# db.json 文件介绍
> 此文件可看作是插件的数据库文件，每个插件均维护自己的 `db.json` 文件  
> 可用于保存群组黑白名单、开关状态、其它需要永久保存的数据


## 1. 文件路径
- `db.json` 文件位于插件根目录，与 `main.py` 同路径
- 没有此文件时，需要自己手动创建

## 2. 文件内容
`db.json` 文件内容示例：
```json
{
    "is_open": true,
    "is_at": true,
    "group_whitelist": [855013471],
    "group_blacklist": []
}
```
- `is_open` 为此插件的开关
- `is_at` 为此插件回复时是否@触发的成员
- `group_whitelist` 群组白名单，白名单不为空时，只有在此白名单的群组才会触发此插件
- `group_blacklist` 群组黑名单
- **上面 4 个变量为插件内置变量，会自动加载并进行判断**
- 还可以存储其它任何自定义变量，后通过 `self.db['name']` 来使用
- 自定义变量的使用与逻辑判断，需要自行写代码处理

## 3. 文件的加载与保存
在插件类的 `__init__()` 初始化方法中添加 `self.fdir` 和 `self.db` 即可，代码如下：
```python
import os

from plugins.base import Base


class Plugin(Base):
    def __init__(self):
        super().__init__()
        self.fdir = os.path.dirname(os.path.abspath(__file__)) # [!code focus]
        self.db = self.load_config() # [!code focus]
```
- 暂时只能手动修改并保存 `db.json` 文件

## 4. 与环境变量的比较
- 可将变量存于 `db.json` 文件中来代替存于环境变量
- 环境变量常用于存储较少且简单的数据
