# 如何创建插件

## 1. 创建插件目录
- 在 `ws/plugins/` 目录下，创建新插件目录

## 2. 编写插件 `main.py` 文件代码
- 以天气预报功能为例
- 进入插件目录，创建 `main.py` 文件
    ```python
    from ..base import Base


    class Plugin(Base):
        """天气插件"""
        def __init__(self):
            super().__init__()

        def is_match(self, message):
            """检测是否匹配此插件"""
            if message.startswith('\tq'):
                return True
            else:
                return False

        async def handle(self, message):
            city = message[3:].strip()
            # TODO 获取城市天气
            res = '多云转晴'
            msg = f'{city}今日{res}'
            return msg
    ```
    - 插件类是固定的名为 `Plugin` 的类，并继承插件基类 `Base` 类
    - 触发指令是 `\tq`，比如 `\tq 北京` 会回复北京今天的天气预报
    - 获取天气的方法这里省略，可以通过天气api、或者天气爬虫等方式获取实时天气


## 3. 测试插件
- 重启机器人，启动时会自动加载新插件
- 根据插件触发方式，进行手动触发测试；比如 `\tq 北京`
